# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.column_types_.post import ColumnTypesCreate
from galv.paths.column_types_.get import ColumnTypesList
from galv.paths.column_types_id_.patch import ColumnTypesPartialUpdate
from galv.paths.column_types_id_.get import ColumnTypesRetrieve


class ColumnTypesApi(
    ColumnTypesCreate,
    ColumnTypesList,
    ColumnTypesPartialUpdate,
    ColumnTypesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PaginatedCellFamilyList(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            count = schemas.IntSchema
            
            
            class next(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'uri'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'next':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class previous(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'uri'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'previous':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class results(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['CellFamily']:
                        return CellFamily
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['CellFamily'], typing.List['CellFamily']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'results':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'CellFamily':
                    return super().__getitem__(i)
            __annotations__ = {
                "count": count,
                "next": next,
                "previous": previous,
                "results": results,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["next"]) -> MetaOapg.properties.next: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["previous"]) -> MetaOapg.properties.previous: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["results"]) -> MetaOapg.properties.results: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["count", "next", "previous", "results", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> typing.Union[MetaOapg.properties.count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["next"]) -> typing.Union[MetaOapg.properties.next, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["previous"]) -> typing.Union[MetaOapg.properties.previous, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["results"]) -> typing.Union[MetaOapg.properties.results, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["count", "next", "previous", "results", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        next: typing.Union[MetaOapg.properties.next, None, str, schemas.Unset] = schemas.unset,
        previous: typing.Union[MetaOapg.properties.previous, None, str, schemas.Unset] = schemas.unset,
        results: typing.Union[MetaOapg.properties.results, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaginatedCellFamilyList':
        return super().__new__(
            cls,
            *_args,
            count=count,
            next=next,
            previous=previous,
            results=results,
            _configuration=_configuration,
            **kwargs,
        )

from galv.model.cell_family import CellFamily



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class ObservedFile(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "has_required_columns",
            "parquet_partitions",
            "summary",
            "mapping",
            "first_sample_no",
            "last_observed_time",
            "png",
            "url",
            "harvester",
            "last_observed_size",
            "last_sample_no",
            "path",
            "parser",
            "extra_metadata",
            "permissions",
            "num_rows",
            "upload_info",
            "id",
            "state",
            "applicable_mappings",
            "upload_errors",
        }
        
        class properties:
            url = schemas.StrSchema
            id = schemas.UUIDSchema
            path = schemas.StrSchema
            harvester = schemas.StrSchema
            
            
            class state(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "RETRY IMPORT": "RETRY_IMPORT",
                        "IMPORT FAILED": "IMPORT_FAILED",
                        "UNSTABLE": "UNSTABLE",
                        "GROWING": "GROWING",
                        "STABLE": "STABLE",
                        "IMPORTING": "IMPORTING",
                        "AWAITING MAP ASSIGNMENT": "AWAITING_MAP_ASSIGNMENT",
                        "MAP ASSIGNED": "MAP_ASSIGNED",
                        "IMPORTED": "IMPORTED",
                    }
                
                @schemas.classproperty
                def RETRY_IMPORT(cls):
                    return cls("RETRY IMPORT")
                
                @schemas.classproperty
                def IMPORT_FAILED(cls):
                    return cls("IMPORT FAILED")
                
                @schemas.classproperty
                def UNSTABLE(cls):
                    return cls("UNSTABLE")
                
                @schemas.classproperty
                def GROWING(cls):
                    return cls("GROWING")
                
                @schemas.classproperty
                def STABLE(cls):
                    return cls("STABLE")
                
                @schemas.classproperty
                def IMPORTING(cls):
                    return cls("IMPORTING")
                
                @schemas.classproperty
                def AWAITING_MAP_ASSIGNMENT(cls):
                    return cls("AWAITING MAP ASSIGNMENT")
                
                @schemas.classproperty
                def MAP_ASSIGNED(cls):
                    return cls("MAP ASSIGNED")
                
                @schemas.classproperty
                def IMPORTED(cls):
                    return cls("IMPORTED")
            
            
            class parser(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'parser':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class upload_errors(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'upload_errors':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class num_rows(
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'num_rows':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class first_sample_no(
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'first_sample_no':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class last_sample_no(
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'last_sample_no':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class last_observed_time(
                schemas.DateTimeBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'date-time'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, datetime, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'last_observed_time':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            last_observed_size = schemas.IntSchema
            mapping = schemas.StrSchema
            has_required_columns = schemas.BoolSchema
            
            
            class parquet_partitions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'parquet_partitions':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class extra_metadata(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
            
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'extra_metadata':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class summary(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
            
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'summary':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class png(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'uri'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'png':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            applicable_mappings = schemas.StrSchema
            
            
            class upload_info(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
            
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'upload_info':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class permissions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        read = schemas.BoolSchema
                        write = schemas.BoolSchema
                        create = schemas.BoolSchema
                        __annotations__ = {
                            "read": read,
                            "write": write,
                            "create": create,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["read"]) -> MetaOapg.properties.read: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["write"]) -> MetaOapg.properties.write: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["create"]) -> MetaOapg.properties.create: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["read"]) -> typing.Union[MetaOapg.properties.read, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["write"]) -> typing.Union[MetaOapg.properties.write, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["create"]) -> typing.Union[MetaOapg.properties.create, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    read: typing.Union[MetaOapg.properties.read, bool, schemas.Unset] = schemas.unset,
                    write: typing.Union[MetaOapg.properties.write, bool, schemas.Unset] = schemas.unset,
                    create: typing.Union[MetaOapg.properties.create, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'permissions':
                    return super().__new__(
                        cls,
                        *_args,
                        read=read,
                        write=write,
                        create=create,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "url": url,
                "id": id,
                "path": path,
                "harvester": harvester,
                "state": state,
                "parser": parser,
                "upload_errors": upload_errors,
                "num_rows": num_rows,
                "first_sample_no": first_sample_no,
                "last_sample_no": last_sample_no,
                "last_observed_time": last_observed_time,
                "last_observed_size": last_observed_size,
                "mapping": mapping,
                "has_required_columns": has_required_columns,
                "parquet_partitions": parquet_partitions,
                "extra_metadata": extra_metadata,
                "summary": summary,
                "png": png,
                "applicable_mappings": applicable_mappings,
                "upload_info": upload_info,
                "permissions": permissions,
                "name": name,
            }
    
    has_required_columns: MetaOapg.properties.has_required_columns
    parquet_partitions: MetaOapg.properties.parquet_partitions
    summary: MetaOapg.properties.summary
    mapping: MetaOapg.properties.mapping
    first_sample_no: MetaOapg.properties.first_sample_no
    last_observed_time: MetaOapg.properties.last_observed_time
    png: MetaOapg.properties.png
    url: MetaOapg.properties.url
    harvester: MetaOapg.properties.harvester
    last_observed_size: MetaOapg.properties.last_observed_size
    last_sample_no: MetaOapg.properties.last_sample_no
    path: MetaOapg.properties.path
    parser: MetaOapg.properties.parser
    extra_metadata: MetaOapg.properties.extra_metadata
    permissions: MetaOapg.properties.permissions
    num_rows: MetaOapg.properties.num_rows
    upload_info: MetaOapg.properties.upload_info
    id: MetaOapg.properties.id
    state: MetaOapg.properties.state
    applicable_mappings: MetaOapg.properties.applicable_mappings
    upload_errors: MetaOapg.properties.upload_errors
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["harvester"]) -> MetaOapg.properties.harvester: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state"]) -> MetaOapg.properties.state: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parser"]) -> MetaOapg.properties.parser: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["upload_errors"]) -> MetaOapg.properties.upload_errors: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["num_rows"]) -> MetaOapg.properties.num_rows: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_sample_no"]) -> MetaOapg.properties.first_sample_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_sample_no"]) -> MetaOapg.properties.last_sample_no: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_observed_time"]) -> MetaOapg.properties.last_observed_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_observed_size"]) -> MetaOapg.properties.last_observed_size: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mapping"]) -> MetaOapg.properties.mapping: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["has_required_columns"]) -> MetaOapg.properties.has_required_columns: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parquet_partitions"]) -> MetaOapg.properties.parquet_partitions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra_metadata"]) -> MetaOapg.properties.extra_metadata: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["summary"]) -> MetaOapg.properties.summary: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["png"]) -> MetaOapg.properties.png: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["applicable_mappings"]) -> MetaOapg.properties.applicable_mappings: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["upload_info"]) -> MetaOapg.properties.upload_info: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["url", "id", "path", "harvester", "state", "parser", "upload_errors", "num_rows", "first_sample_no", "last_sample_no", "last_observed_time", "last_observed_size", "mapping", "has_required_columns", "parquet_partitions", "extra_metadata", "summary", "png", "applicable_mappings", "upload_info", "permissions", "name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["harvester"]) -> MetaOapg.properties.harvester: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state"]) -> MetaOapg.properties.state: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parser"]) -> MetaOapg.properties.parser: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["upload_errors"]) -> MetaOapg.properties.upload_errors: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["num_rows"]) -> MetaOapg.properties.num_rows: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_sample_no"]) -> MetaOapg.properties.first_sample_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_sample_no"]) -> MetaOapg.properties.last_sample_no: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_observed_time"]) -> MetaOapg.properties.last_observed_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_observed_size"]) -> MetaOapg.properties.last_observed_size: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mapping"]) -> MetaOapg.properties.mapping: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["has_required_columns"]) -> MetaOapg.properties.has_required_columns: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parquet_partitions"]) -> MetaOapg.properties.parquet_partitions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra_metadata"]) -> MetaOapg.properties.extra_metadata: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["summary"]) -> MetaOapg.properties.summary: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["png"]) -> MetaOapg.properties.png: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["applicable_mappings"]) -> MetaOapg.properties.applicable_mappings: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["upload_info"]) -> MetaOapg.properties.upload_info: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["url", "id", "path", "harvester", "state", "parser", "upload_errors", "num_rows", "first_sample_no", "last_sample_no", "last_observed_time", "last_observed_size", "mapping", "has_required_columns", "parquet_partitions", "extra_metadata", "summary", "png", "applicable_mappings", "upload_info", "permissions", "name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        has_required_columns: typing.Union[MetaOapg.properties.has_required_columns, bool, ],
        parquet_partitions: typing.Union[MetaOapg.properties.parquet_partitions, list, tuple, ],
        summary: typing.Union[MetaOapg.properties.summary, dict, frozendict.frozendict, None, ],
        mapping: typing.Union[MetaOapg.properties.mapping, str, ],
        first_sample_no: typing.Union[MetaOapg.properties.first_sample_no, None, decimal.Decimal, int, ],
        last_observed_time: typing.Union[MetaOapg.properties.last_observed_time, None, str, datetime, ],
        png: typing.Union[MetaOapg.properties.png, None, str, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        harvester: typing.Union[MetaOapg.properties.harvester, str, ],
        last_observed_size: typing.Union[MetaOapg.properties.last_observed_size, decimal.Decimal, int, ],
        last_sample_no: typing.Union[MetaOapg.properties.last_sample_no, None, decimal.Decimal, int, ],
        path: typing.Union[MetaOapg.properties.path, str, ],
        parser: typing.Union[MetaOapg.properties.parser, None, str, ],
        extra_metadata: typing.Union[MetaOapg.properties.extra_metadata, dict, frozendict.frozendict, None, ],
        permissions: typing.Union[MetaOapg.properties.permissions, dict, frozendict.frozendict, ],
        num_rows: typing.Union[MetaOapg.properties.num_rows, None, decimal.Decimal, int, ],
        upload_info: typing.Union[MetaOapg.properties.upload_info, dict, frozendict.frozendict, None, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        state: typing.Union[MetaOapg.properties.state, str, ],
        applicable_mappings: typing.Union[MetaOapg.properties.applicable_mappings, str, ],
        upload_errors: typing.Union[MetaOapg.properties.upload_errors, list, tuple, ],
        name: typing.Union[MetaOapg.properties.name, None, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ObservedFile':
        return super().__new__(
            cls,
            *_args,
            has_required_columns=has_required_columns,
            parquet_partitions=parquet_partitions,
            summary=summary,
            mapping=mapping,
            first_sample_no=first_sample_no,
            last_observed_time=last_observed_time,
            png=png,
            url=url,
            harvester=harvester,
            last_observed_size=last_observed_size,
            last_sample_no=last_sample_no,
            path=path,
            parser=parser,
            extra_metadata=extra_metadata,
            permissions=permissions,
            num_rows=num_rows,
            upload_info=upload_info,
            id=id,
            state=state,
            applicable_mappings=applicable_mappings,
            upload_errors=upload_errors,
            name=name,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.files_id_applicable_mappings_.get import FilesApplicableMappingsRetrieve
from galv.paths.files_id_extra_metadata_.get import FilesExtraMetadataRetrieve
from galv.paths.files_.get import FilesList
from galv.paths.files_id_.patch import FilesPartialUpdate
from galv.paths.files_id_png_.get import FilesPngRetrieve
from galv.paths.files_id_reimport_.get import FilesReimportRetrieve
from galv.paths.files_id_.get import FilesRetrieve
from galv.paths.files_id_summary_.get import FilesSummaryRetrieve


class FilesApi(
    FilesApplicableMappingsRetrieve,
    FilesExtraMetadataRetrieve,
    FilesList,
    FilesPartialUpdate,
    FilesPngRetrieve,
    FilesReimportRetrieve,
    FilesRetrieve,
    FilesSummaryRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.cycler_tests_.post import CyclerTestsCreate
from galv.paths.cycler_tests_id_.delete import CyclerTestsDestroy
from galv.paths.cycler_tests_.get import CyclerTestsList
from galv.paths.cycler_tests_id_.patch import CyclerTestsPartialUpdate
from galv.paths.cycler_tests_id_.get import CyclerTestsRetrieve


class CyclerTestsApi(
    CyclerTestsCreate,
    CyclerTestsDestroy,
    CyclerTestsList,
    CyclerTestsPartialUpdate,
    CyclerTestsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PatchedGalvStorageTypeRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class priority(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 32767
                    inclusive_minimum = -32768
            enabled = schemas.BoolSchema
            __annotations__ = {
                "name": name,
                "priority": priority,
                "enabled": enabled,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["priority"]) -> MetaOapg.properties.priority: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "priority", "enabled", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["priority"]) -> typing.Union[MetaOapg.properties.priority, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> typing.Union[MetaOapg.properties.enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "priority", "enabled", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, None, str, schemas.Unset] = schemas.unset,
        priority: typing.Union[MetaOapg.properties.priority, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        enabled: typing.Union[MetaOapg.properties.enabled, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchedGalvStorageTypeRequest':
        return super().__new__(
            cls,
            *_args,
            name=name,
            priority=priority,
            enabled=enabled,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.monitored_paths_.post import MonitoredPathsCreate
from galv.paths.monitored_paths_id_.delete import MonitoredPathsDestroy
from galv.paths.monitored_paths_.get import MonitoredPathsList
from galv.paths.monitored_paths_id_.patch import MonitoredPathsPartialUpdate
from galv.paths.monitored_paths_id_.get import MonitoredPathsRetrieve


class MonitoredPathsApi(
    MonitoredPathsCreate,
    MonitoredPathsDestroy,
    MonitoredPathsList,
    MonitoredPathsPartialUpdate,
    MonitoredPathsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

import unittest

import galv
from galv.model.activation_response import ActivationResponse
from galv import configuration


class TestActivationResponse(unittest.TestCase):
    """ActivationResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.validation_schemas_.post import ValidationSchemasCreate
from galv.paths.validation_schemas_id_.delete import ValidationSchemasDestroy
from galv.paths.validation_schemas_keys_.get import ValidationSchemasKeysRetrieve
from galv.paths.validation_schemas_.get import ValidationSchemasList
from galv.paths.validation_schemas_id_.patch import ValidationSchemasPartialUpdate
from galv.paths.validation_schemas_id_.get import ValidationSchemasRetrieve
from galv.paths.validation_schemas_id_.put import ValidationSchemasUpdate


class ValidationSchemasApi(
    ValidationSchemasCreate,
    ValidationSchemasDestroy,
    ValidationSchemasKeysRetrieve,
    ValidationSchemasList,
    ValidationSchemasPartialUpdate,
    ValidationSchemasRetrieve,
    ValidationSchemasUpdate,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from galv.paths.experiments_id_.get import ApiForget
from galv.paths.experiments_id_.delete import ApiFordelete
from galv.paths.experiments_id_.patch import ApiForpatch


class ExperimentsId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.column_mappings_.post import ColumnMappingsCreate
from galv.paths.column_mappings_id_.delete import ColumnMappingsDestroy
from galv.paths.column_mappings_.get import ColumnMappingsList
from galv.paths.column_mappings_id_.patch import ColumnMappingsPartialUpdate
from galv.paths.column_mappings_id_.get import ColumnMappingsRetrieve


class ColumnMappingsApi(
    ColumnMappingsCreate,
    ColumnMappingsDestroy,
    ColumnMappingsList,
    ColumnMappingsPartialUpdate,
    ColumnMappingsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from galv.paths.teams_ import Api

from galv.paths import PathValues

path = PathValues.TEAMS_


# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class KnoxTokenFull(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "created",
            "permissions",
            "name",
            "expiry",
            "id",
            "url",
            "token",
        }
        
        class properties:
            url = schemas.StrSchema
            id = schemas.IntSchema
            name = schemas.StrSchema
            created = schemas.DateTimeSchema
            
            
            class expiry(
                schemas.DateTimeBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'date-time'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, datetime, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'expiry':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            token = schemas.StrSchema
            
            
            class permissions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        read = schemas.BoolSchema
                        write = schemas.BoolSchema
                        create = schemas.BoolSchema
                        __annotations__ = {
                            "read": read,
                            "write": write,
                            "create": create,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["read"]) -> MetaOapg.properties.read: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["write"]) -> MetaOapg.properties.write: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["create"]) -> MetaOapg.properties.create: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["read"]) -> typing.Union[MetaOapg.properties.read, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["write"]) -> typing.Union[MetaOapg.properties.write, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["create"]) -> typing.Union[MetaOapg.properties.create, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    read: typing.Union[MetaOapg.properties.read, bool, schemas.Unset] = schemas.unset,
                    write: typing.Union[MetaOapg.properties.write, bool, schemas.Unset] = schemas.unset,
                    create: typing.Union[MetaOapg.properties.create, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'permissions':
                    return super().__new__(
                        cls,
                        *_args,
                        read=read,
                        write=write,
                        create=create,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "url": url,
                "id": id,
                "name": name,
                "created": created,
                "expiry": expiry,
                "token": token,
                "permissions": permissions,
            }
    
    created: MetaOapg.properties.created
    permissions: MetaOapg.properties.permissions
    name: MetaOapg.properties.name
    expiry: MetaOapg.properties.expiry
    id: MetaOapg.properties.id
    url: MetaOapg.properties.url
    token: MetaOapg.properties.token
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiry"]) -> MetaOapg.properties.expiry: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token"]) -> MetaOapg.properties.token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["url", "id", "name", "created", "expiry", "token", "permissions", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created"]) -> MetaOapg.properties.created: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiry"]) -> MetaOapg.properties.expiry: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token"]) -> MetaOapg.properties.token: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["url", "id", "name", "created", "expiry", "token", "permissions", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        created: typing.Union[MetaOapg.properties.created, str, datetime, ],
        permissions: typing.Union[MetaOapg.properties.permissions, dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        expiry: typing.Union[MetaOapg.properties.expiry, None, str, datetime, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        token: typing.Union[MetaOapg.properties.token, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'KnoxTokenFull':
        return super().__new__(
            cls,
            *_args,
            created=created,
            permissions=permissions,
            name=name,
            expiry=expiry,
            id=id,
            url=url,
            token=token,
            _configuration=_configuration,
            **kwargs,
        )



from galv.paths.validation_schemas_id_.get import ApiForget
from galv.paths.validation_schemas_id_.put import ApiForput
from galv.paths.validation_schemas_id_.delete import ApiFordelete
from galv.paths.validation_schemas_id_.patch import ApiForpatch


class ValidationSchemasId(
    ApiForget,
    ApiForput,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PatchedMonitoredPathRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class path(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    min_length = 1
            
            
            class regex(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'regex':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class stable_time(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 32767
                    inclusive_minimum = 0
            active = schemas.BoolSchema
            
            
            class max_partition_line_count(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 2147483647
                    inclusive_minimum = 0
            
            
            class read_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        2: "POSITIVE_2",
                        1: "POSITIVE_1",
                        0: "POSITIVE_0",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'read_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class edit_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'edit_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class delete_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'delete_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "path": path,
                "regex": regex,
                "stable_time": stable_time,
                "active": active,
                "max_partition_line_count": max_partition_line_count,
                "read_access_level": read_access_level,
                "edit_access_level": edit_access_level,
                "delete_access_level": delete_access_level,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["regex"]) -> MetaOapg.properties.regex: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["stable_time"]) -> MetaOapg.properties.stable_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["active"]) -> MetaOapg.properties.active: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_partition_line_count"]) -> MetaOapg.properties.max_partition_line_count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["read_access_level"]) -> MetaOapg.properties.read_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["edit_access_level"]) -> MetaOapg.properties.edit_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["delete_access_level"]) -> MetaOapg.properties.delete_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["path", "regex", "stable_time", "active", "max_partition_line_count", "read_access_level", "edit_access_level", "delete_access_level", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path"]) -> typing.Union[MetaOapg.properties.path, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["regex"]) -> typing.Union[MetaOapg.properties.regex, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["stable_time"]) -> typing.Union[MetaOapg.properties.stable_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["active"]) -> typing.Union[MetaOapg.properties.active, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_partition_line_count"]) -> typing.Union[MetaOapg.properties.max_partition_line_count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["read_access_level"]) -> typing.Union[MetaOapg.properties.read_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["edit_access_level"]) -> typing.Union[MetaOapg.properties.edit_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["delete_access_level"]) -> typing.Union[MetaOapg.properties.delete_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["path", "regex", "stable_time", "active", "max_partition_line_count", "read_access_level", "edit_access_level", "delete_access_level", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        path: typing.Union[MetaOapg.properties.path, str, schemas.Unset] = schemas.unset,
        regex: typing.Union[MetaOapg.properties.regex, None, str, schemas.Unset] = schemas.unset,
        stable_time: typing.Union[MetaOapg.properties.stable_time, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        active: typing.Union[MetaOapg.properties.active, bool, schemas.Unset] = schemas.unset,
        max_partition_line_count: typing.Union[MetaOapg.properties.max_partition_line_count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        read_access_level: typing.Union[MetaOapg.properties.read_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        edit_access_level: typing.Union[MetaOapg.properties.edit_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        delete_access_level: typing.Union[MetaOapg.properties.delete_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchedMonitoredPathRequest':
        return super().__new__(
            cls,
            *_args,
            path=path,
            regex=regex,
            stable_time=stable_time,
            active=active,
            max_partition_line_count=max_partition_line_count,
            read_access_level=read_access_level,
            edit_access_level=edit_access_level,
            delete_access_level=delete_access_level,
            _configuration=_configuration,
            **kwargs,
        )



from galv.paths.equipment_families_id_.get import ApiForget
from galv.paths.equipment_families_id_.delete import ApiFordelete
from galv.paths.equipment_families_id_.patch import ApiForpatch


class EquipmentFamiliesId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from galv import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401

from galv.model.paginated_observed_file_list import PaginatedObservedFileList

from . import path

# Query params
LimitSchema = schemas.IntSchema
OffsetSchema = schemas.IntSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'offset': typing.Union[OffsetSchema, decimal.Decimal, int, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_offset = api_client.QueryParameter(
    name="offset",
    style=api_client.ParameterStyle.FORM,
    schema=OffsetSchema,
    explode=True,
)
_auth = [
    'knoxTokenAuth',
    'cookieAuth',
    'harvesterAuth',
]
SchemaFor200ResponseBodyApplicationJson = PaginatedObservedFileList
SchemaFor200ResponseBodyApplicationOctetStream = PaginatedObservedFileList


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
        SchemaFor200ResponseBodyApplicationOctetStream,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
        'application/octet-stream': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationOctetStream),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/json',
    'application/octet-stream',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _files_list_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _files_list_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _files_list_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _files_list_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        View Files on a Path you can access
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_offset,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class FilesList(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def files_list(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def files_list(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def files_list(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def files_list(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._files_list_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._files_list_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





import typing_extensions

from galv.paths import PathValues
from galv.apis.paths.access_levels_ import AccessLevels
from galv.apis.paths.activate_ import Activate
from galv.apis.paths.additional_storage_ import AdditionalStorage
from galv.apis.paths.additional_storage_id_ import AdditionalStorageId
from galv.apis.paths.arbitrary_files_ import ArbitraryFiles
from galv.apis.paths.arbitrary_files_id_ import ArbitraryFilesId
from galv.apis.paths.arbitrary_files_id_file_ import ArbitraryFilesIdFile
from galv.apis.paths.cell_chemistries_ import CellChemistries
from galv.apis.paths.cell_families_ import CellFamilies
from galv.apis.paths.cell_families_id_ import CellFamiliesId
from galv.apis.paths.cell_form_factors_ import CellFormFactors
from galv.apis.paths.cell_manufacturers_ import CellManufacturers
from galv.apis.paths.cell_models_ import CellModels
from galv.apis.paths.cells_ import Cells
from galv.apis.paths.cells_id_ import CellsId
from galv.apis.paths.cells_id_rdf_ import CellsIdRdf
from galv.apis.paths.column_mappings_ import ColumnMappings
from galv.apis.paths.column_mappings_id_ import ColumnMappingsId
from galv.apis.paths.column_types_ import ColumnTypes
from galv.apis.paths.column_types_id_ import ColumnTypesId
from galv.apis.paths.create_token_ import CreateToken
from galv.apis.paths.cycler_tests_ import CyclerTests
from galv.apis.paths.cycler_tests_id_ import CyclerTestsId
from galv.apis.paths.equipment_ import Equipment
from galv.apis.paths.equipment_id_ import EquipmentId
from galv.apis.paths.equipment_families_ import EquipmentFamilies
from galv.apis.paths.equipment_families_id_ import EquipmentFamiliesId
from galv.apis.paths.equipment_manufacturers_ import EquipmentManufacturers
from galv.apis.paths.equipment_models_ import EquipmentModels
from galv.apis.paths.equipment_types_ import EquipmentTypes
from galv.apis.paths.experiments_ import Experiments
from galv.apis.paths.experiments_id_ import ExperimentsId
from galv.apis.paths.files_ import Files
from galv.apis.paths.files_id_ import FilesId
from galv.apis.paths.files_id_applicable_mappings_ import FilesIdApplicableMappings
from galv.apis.paths.files_id_extra_metadata_ import FilesIdExtraMetadata
from galv.apis.paths.files_id_png_ import FilesIdPng
from galv.apis.paths.files_id_reimport_ import FilesIdReimport
from galv.apis.paths.files_id_summary_ import FilesIdSummary
from galv.apis.paths.galv_storage_ import GalvStorage
from galv.apis.paths.galv_storage_id_ import GalvStorageId
from galv.apis.paths.harvest_errors_ import HarvestErrors
from galv.apis.paths.harvest_errors_id_ import HarvestErrorsId
from galv.apis.paths.harvesters_ import Harvesters
from galv.apis.paths.harvesters_id_ import HarvestersId
from galv.apis.paths.labs_ import Labs
from galv.apis.paths.labs_id_ import LabsId
from galv.apis.paths.login_ import Login
from galv.apis.paths.monitored_paths_ import MonitoredPaths
from galv.apis.paths.monitored_paths_id_ import MonitoredPathsId
from galv.apis.paths.parquet_partitions_ import ParquetPartitions
from galv.apis.paths.parquet_partitions_id_ import ParquetPartitionsId
from galv.apis.paths.parquet_partitions_id_file_ import ParquetPartitionsIdFile
from galv.apis.paths.schedule_families_ import ScheduleFamilies
from galv.apis.paths.schedule_families_id_ import ScheduleFamiliesId
from galv.apis.paths.schedule_identifiers_ import ScheduleIdentifiers
from galv.apis.paths.schedules_ import Schedules
from galv.apis.paths.schedules_id_ import SchedulesId
from galv.apis.paths.schema_validations_ import SchemaValidations
from galv.apis.paths.schema_validations_id_ import SchemaValidationsId
from galv.apis.paths.teams_ import Teams
from galv.apis.paths.teams_id_ import TeamsId
from galv.apis.paths.tokens_ import Tokens
from galv.apis.paths.tokens_id_ import TokensId
from galv.apis.paths.units_ import Units
from galv.apis.paths.units_id_ import UnitsId
from galv.apis.paths.users_ import Users
from galv.apis.paths.users_id_ import UsersId
from galv.apis.paths.validation_schemas_ import ValidationSchemas
from galv.apis.paths.validation_schemas_id_ import ValidationSchemasId
from galv.apis.paths.validation_schemas_keys_ import ValidationSchemasKeys

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.ACCESS_LEVELS_: AccessLevels,
        PathValues.ACTIVATE_: Activate,
        PathValues.ADDITIONAL_STORAGE_: AdditionalStorage,
        PathValues.ADDITIONAL_STORAGE_ID_: AdditionalStorageId,
        PathValues.ARBITRARY_FILES_: ArbitraryFiles,
        PathValues.ARBITRARY_FILES_ID_: ArbitraryFilesId,
        PathValues.ARBITRARY_FILES_ID_FILE_: ArbitraryFilesIdFile,
        PathValues.CELL_CHEMISTRIES_: CellChemistries,
        PathValues.CELL_FAMILIES_: CellFamilies,
        PathValues.CELL_FAMILIES_ID_: CellFamiliesId,
        PathValues.CELL_FORM_FACTORS_: CellFormFactors,
        PathValues.CELL_MANUFACTURERS_: CellManufacturers,
        PathValues.CELL_MODELS_: CellModels,
        PathValues.CELLS_: Cells,
        PathValues.CELLS_ID_: CellsId,
        PathValues.CELLS_ID_RDF_: CellsIdRdf,
        PathValues.COLUMN_MAPPINGS_: ColumnMappings,
        PathValues.COLUMN_MAPPINGS_ID_: ColumnMappingsId,
        PathValues.COLUMN_TYPES_: ColumnTypes,
        PathValues.COLUMN_TYPES_ID_: ColumnTypesId,
        PathValues.CREATE_TOKEN_: CreateToken,
        PathValues.CYCLER_TESTS_: CyclerTests,
        PathValues.CYCLER_TESTS_ID_: CyclerTestsId,
        PathValues.EQUIPMENT_: Equipment,
        PathValues.EQUIPMENT_ID_: EquipmentId,
        PathValues.EQUIPMENT_FAMILIES_: EquipmentFamilies,
        PathValues.EQUIPMENT_FAMILIES_ID_: EquipmentFamiliesId,
        PathValues.EQUIPMENT_MANUFACTURERS_: EquipmentManufacturers,
        PathValues.EQUIPMENT_MODELS_: EquipmentModels,
        PathValues.EQUIPMENT_TYPES_: EquipmentTypes,
        PathValues.EXPERIMENTS_: Experiments,
        PathValues.EXPERIMENTS_ID_: ExperimentsId,
        PathValues.FILES_: Files,
        PathValues.FILES_ID_: FilesId,
        PathValues.FILES_ID_APPLICABLE_MAPPINGS_: FilesIdApplicableMappings,
        PathValues.FILES_ID_EXTRA_METADATA_: FilesIdExtraMetadata,
        PathValues.FILES_ID_PNG_: FilesIdPng,
        PathValues.FILES_ID_REIMPORT_: FilesIdReimport,
        PathValues.FILES_ID_SUMMARY_: FilesIdSummary,
        PathValues.GALV_STORAGE_: GalvStorage,
        PathValues.GALV_STORAGE_ID_: GalvStorageId,
        PathValues.HARVEST_ERRORS_: HarvestErrors,
        PathValues.HARVEST_ERRORS_ID_: HarvestErrorsId,
        PathValues.HARVESTERS_: Harvesters,
        PathValues.HARVESTERS_ID_: HarvestersId,
        PathValues.LABS_: Labs,
        PathValues.LABS_ID_: LabsId,
        PathValues.LOGIN_: Login,
        PathValues.MONITORED_PATHS_: MonitoredPaths,
        PathValues.MONITORED_PATHS_ID_: MonitoredPathsId,
        PathValues.PARQUET_PARTITIONS_: ParquetPartitions,
        PathValues.PARQUET_PARTITIONS_ID_: ParquetPartitionsId,
        PathValues.PARQUET_PARTITIONS_ID_FILE_: ParquetPartitionsIdFile,
        PathValues.SCHEDULE_FAMILIES_: ScheduleFamilies,
        PathValues.SCHEDULE_FAMILIES_ID_: ScheduleFamiliesId,
        PathValues.SCHEDULE_IDENTIFIERS_: ScheduleIdentifiers,
        PathValues.SCHEDULES_: Schedules,
        PathValues.SCHEDULES_ID_: SchedulesId,
        PathValues.SCHEMA_VALIDATIONS_: SchemaValidations,
        PathValues.SCHEMA_VALIDATIONS_ID_: SchemaValidationsId,
        PathValues.TEAMS_: Teams,
        PathValues.TEAMS_ID_: TeamsId,
        PathValues.TOKENS_: Tokens,
        PathValues.TOKENS_ID_: TokensId,
        PathValues.UNITS_: Units,
        PathValues.UNITS_ID_: UnitsId,
        PathValues.USERS_: Users,
        PathValues.USERS_ID_: UsersId,
        PathValues.VALIDATION_SCHEMAS_: ValidationSchemas,
        PathValues.VALIDATION_SCHEMAS_ID_: ValidationSchemasId,
        PathValues.VALIDATION_SCHEMAS_KEYS_: ValidationSchemasKeys,
    }
)

path_to_api = PathToApi(
    {
        PathValues.ACCESS_LEVELS_: AccessLevels,
        PathValues.ACTIVATE_: Activate,
        PathValues.ADDITIONAL_STORAGE_: AdditionalStorage,
        PathValues.ADDITIONAL_STORAGE_ID_: AdditionalStorageId,
        PathValues.ARBITRARY_FILES_: ArbitraryFiles,
        PathValues.ARBITRARY_FILES_ID_: ArbitraryFilesId,
        PathValues.ARBITRARY_FILES_ID_FILE_: ArbitraryFilesIdFile,
        PathValues.CELL_CHEMISTRIES_: CellChemistries,
        PathValues.CELL_FAMILIES_: CellFamilies,
        PathValues.CELL_FAMILIES_ID_: CellFamiliesId,
        PathValues.CELL_FORM_FACTORS_: CellFormFactors,
        PathValues.CELL_MANUFACTURERS_: CellManufacturers,
        PathValues.CELL_MODELS_: CellModels,
        PathValues.CELLS_: Cells,
        PathValues.CELLS_ID_: CellsId,
        PathValues.CELLS_ID_RDF_: CellsIdRdf,
        PathValues.COLUMN_MAPPINGS_: ColumnMappings,
        PathValues.COLUMN_MAPPINGS_ID_: ColumnMappingsId,
        PathValues.COLUMN_TYPES_: ColumnTypes,
        PathValues.COLUMN_TYPES_ID_: ColumnTypesId,
        PathValues.CREATE_TOKEN_: CreateToken,
        PathValues.CYCLER_TESTS_: CyclerTests,
        PathValues.CYCLER_TESTS_ID_: CyclerTestsId,
        PathValues.EQUIPMENT_: Equipment,
        PathValues.EQUIPMENT_ID_: EquipmentId,
        PathValues.EQUIPMENT_FAMILIES_: EquipmentFamilies,
        PathValues.EQUIPMENT_FAMILIES_ID_: EquipmentFamiliesId,
        PathValues.EQUIPMENT_MANUFACTURERS_: EquipmentManufacturers,
        PathValues.EQUIPMENT_MODELS_: EquipmentModels,
        PathValues.EQUIPMENT_TYPES_: EquipmentTypes,
        PathValues.EXPERIMENTS_: Experiments,
        PathValues.EXPERIMENTS_ID_: ExperimentsId,
        PathValues.FILES_: Files,
        PathValues.FILES_ID_: FilesId,
        PathValues.FILES_ID_APPLICABLE_MAPPINGS_: FilesIdApplicableMappings,
        PathValues.FILES_ID_EXTRA_METADATA_: FilesIdExtraMetadata,
        PathValues.FILES_ID_PNG_: FilesIdPng,
        PathValues.FILES_ID_REIMPORT_: FilesIdReimport,
        PathValues.FILES_ID_SUMMARY_: FilesIdSummary,
        PathValues.GALV_STORAGE_: GalvStorage,
        PathValues.GALV_STORAGE_ID_: GalvStorageId,
        PathValues.HARVEST_ERRORS_: HarvestErrors,
        PathValues.HARVEST_ERRORS_ID_: HarvestErrorsId,
        PathValues.HARVESTERS_: Harvesters,
        PathValues.HARVESTERS_ID_: HarvestersId,
        PathValues.LABS_: Labs,
        PathValues.LABS_ID_: LabsId,
        PathValues.LOGIN_: Login,
        PathValues.MONITORED_PATHS_: MonitoredPaths,
        PathValues.MONITORED_PATHS_ID_: MonitoredPathsId,
        PathValues.PARQUET_PARTITIONS_: ParquetPartitions,
        PathValues.PARQUET_PARTITIONS_ID_: ParquetPartitionsId,
        PathValues.PARQUET_PARTITIONS_ID_FILE_: ParquetPartitionsIdFile,
        PathValues.SCHEDULE_FAMILIES_: ScheduleFamilies,
        PathValues.SCHEDULE_FAMILIES_ID_: ScheduleFamiliesId,
        PathValues.SCHEDULE_IDENTIFIERS_: ScheduleIdentifiers,
        PathValues.SCHEDULES_: Schedules,
        PathValues.SCHEDULES_ID_: SchedulesId,
        PathValues.SCHEMA_VALIDATIONS_: SchemaValidations,
        PathValues.SCHEMA_VALIDATIONS_ID_: SchemaValidationsId,
        PathValues.TEAMS_: Teams,
        PathValues.TEAMS_ID_: TeamsId,
        PathValues.TOKENS_: Tokens,
        PathValues.TOKENS_ID_: TokensId,
        PathValues.UNITS_: Units,
        PathValues.UNITS_ID_: UnitsId,
        PathValues.USERS_: Users,
        PathValues.USERS_ID_: UsersId,
        PathValues.VALIDATION_SCHEMAS_: ValidationSchemas,
        PathValues.VALIDATION_SCHEMAS_ID_: ValidationSchemasId,
        PathValues.VALIDATION_SCHEMAS_KEYS_: ValidationSchemasKeys,
    }
)



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.equipment_families_.post import EquipmentFamiliesCreate
from galv.paths.equipment_families_id_.delete import EquipmentFamiliesDestroy
from galv.paths.equipment_families_.get import EquipmentFamiliesList
from galv.paths.equipment_families_id_.patch import EquipmentFamiliesPartialUpdate
from galv.paths.equipment_families_id_.get import EquipmentFamiliesRetrieve


class EquipmentFamiliesApi(
    EquipmentFamiliesCreate,
    EquipmentFamiliesDestroy,
    EquipmentFamiliesList,
    EquipmentFamiliesPartialUpdate,
    EquipmentFamiliesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PatchedAdditionalS3StorageTypeRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class quota(
                schemas.Int64Schema
            ):
            
            
                class MetaOapg:
                    format = 'int64'
                    inclusive_maximum = 9223372036854775807
                    inclusive_minimum = -9223372036854775808
            
            
            class priority(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 32767
                    inclusive_minimum = -32768
            enabled = schemas.BoolSchema
            
            
            class bucket_name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'bucket_name':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class location(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'location':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class custom_domain(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'custom_domain':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "name": name,
                "quota": quota,
                "priority": priority,
                "enabled": enabled,
                "bucket_name": bucket_name,
                "location": location,
                "custom_domain": custom_domain,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["quota"]) -> MetaOapg.properties.quota: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["priority"]) -> MetaOapg.properties.priority: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bucket_name"]) -> MetaOapg.properties.bucket_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["location"]) -> MetaOapg.properties.location: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_domain"]) -> MetaOapg.properties.custom_domain: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "quota", "priority", "enabled", "bucket_name", "location", "custom_domain", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["quota"]) -> typing.Union[MetaOapg.properties.quota, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["priority"]) -> typing.Union[MetaOapg.properties.priority, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> typing.Union[MetaOapg.properties.enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bucket_name"]) -> typing.Union[MetaOapg.properties.bucket_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["location"]) -> typing.Union[MetaOapg.properties.location, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_domain"]) -> typing.Union[MetaOapg.properties.custom_domain, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "quota", "priority", "enabled", "bucket_name", "location", "custom_domain", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, None, str, schemas.Unset] = schemas.unset,
        quota: typing.Union[MetaOapg.properties.quota, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        priority: typing.Union[MetaOapg.properties.priority, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        enabled: typing.Union[MetaOapg.properties.enabled, bool, schemas.Unset] = schemas.unset,
        bucket_name: typing.Union[MetaOapg.properties.bucket_name, None, str, schemas.Unset] = schemas.unset,
        location: typing.Union[MetaOapg.properties.location, None, str, schemas.Unset] = schemas.unset,
        custom_domain: typing.Union[MetaOapg.properties.custom_domain, None, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchedAdditionalS3StorageTypeRequest':
        return super().__new__(
            cls,
            *_args,
            name=name,
            quota=quota,
            priority=priority,
            enabled=enabled,
            bucket_name=bucket_name,
            location=location,
            custom_domain=custom_domain,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class User(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "is_superuser",
            "is_staff",
            "permissions",
            "is_lab_admin",
            "id",
            "url",
            "username",
        }
        
        class properties:
            
            
            class username(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 150
                    regex=[{
                        'pattern': r'^[\w.@+-]+$',  # noqa: E501
                    }]
            url = schemas.StrSchema
            id = schemas.IntSchema
            is_staff = schemas.BoolSchema
            is_superuser = schemas.BoolSchema
            is_lab_admin = schemas.BoolSchema
            
            
            class permissions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        read = schemas.BoolSchema
                        write = schemas.BoolSchema
                        create = schemas.BoolSchema
                        __annotations__ = {
                            "read": read,
                            "write": write,
                            "create": create,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["read"]) -> MetaOapg.properties.read: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["write"]) -> MetaOapg.properties.write: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["create"]) -> MetaOapg.properties.create: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["read"]) -> typing.Union[MetaOapg.properties.read, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["write"]) -> typing.Union[MetaOapg.properties.write, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["create"]) -> typing.Union[MetaOapg.properties.create, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    read: typing.Union[MetaOapg.properties.read, bool, schemas.Unset] = schemas.unset,
                    write: typing.Union[MetaOapg.properties.write, bool, schemas.Unset] = schemas.unset,
                    create: typing.Union[MetaOapg.properties.create, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'permissions':
                    return super().__new__(
                        cls,
                        *_args,
                        read=read,
                        write=write,
                        create=create,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class email(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    format = 'email'
                    max_length = 254
            
            
            class first_name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 150
            
            
            class last_name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 150
            __annotations__ = {
                "username": username,
                "url": url,
                "id": id,
                "is_staff": is_staff,
                "is_superuser": is_superuser,
                "is_lab_admin": is_lab_admin,
                "permissions": permissions,
                "email": email,
                "first_name": first_name,
                "last_name": last_name,
            }
    
    is_superuser: MetaOapg.properties.is_superuser
    is_staff: MetaOapg.properties.is_staff
    permissions: MetaOapg.properties.permissions
    is_lab_admin: MetaOapg.properties.is_lab_admin
    id: MetaOapg.properties.id
    url: MetaOapg.properties.url
    username: MetaOapg.properties.username
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["username"]) -> MetaOapg.properties.username: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_staff"]) -> MetaOapg.properties.is_staff: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_superuser"]) -> MetaOapg.properties.is_superuser: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_lab_admin"]) -> MetaOapg.properties.is_lab_admin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_name"]) -> MetaOapg.properties.first_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_name"]) -> MetaOapg.properties.last_name: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["username", "url", "id", "is_staff", "is_superuser", "is_lab_admin", "permissions", "email", "first_name", "last_name", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["username"]) -> MetaOapg.properties.username: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_staff"]) -> MetaOapg.properties.is_staff: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_superuser"]) -> MetaOapg.properties.is_superuser: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_lab_admin"]) -> MetaOapg.properties.is_lab_admin: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> typing.Union[MetaOapg.properties.email, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_name"]) -> typing.Union[MetaOapg.properties.first_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_name"]) -> typing.Union[MetaOapg.properties.last_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["username", "url", "id", "is_staff", "is_superuser", "is_lab_admin", "permissions", "email", "first_name", "last_name", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        is_superuser: typing.Union[MetaOapg.properties.is_superuser, bool, ],
        is_staff: typing.Union[MetaOapg.properties.is_staff, bool, ],
        permissions: typing.Union[MetaOapg.properties.permissions, dict, frozendict.frozendict, ],
        is_lab_admin: typing.Union[MetaOapg.properties.is_lab_admin, bool, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        username: typing.Union[MetaOapg.properties.username, str, ],
        email: typing.Union[MetaOapg.properties.email, str, schemas.Unset] = schemas.unset,
        first_name: typing.Union[MetaOapg.properties.first_name, str, schemas.Unset] = schemas.unset,
        last_name: typing.Union[MetaOapg.properties.last_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'User':
        return super().__new__(
            cls,
            *_args,
            is_superuser=is_superuser,
            is_staff=is_staff,
            permissions=permissions,
            is_lab_admin=is_lab_admin,
            id=id,
            url=url,
            username=username,
            email=email,
            first_name=first_name,
            last_name=last_name,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

# flake8: noqa

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

__version__ = "2.1.37"

# import ApiClient
from galv.api_client import ApiClient

# import Configuration
from galv.configuration import Configuration

# import exceptions
from galv.exceptions import OpenApiException
from galv.exceptions import ApiAttributeError
from galv.exceptions import ApiTypeError
from galv.exceptions import ApiValueError
from galv.exceptions import ApiKeyError
from galv.exceptions import ApiException



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from galv.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCESS_LEVELS = "access_levels"
    ACTIVATE = "activate"
    ADDITIONAL_STORAGE = "additional_storage"
    ARBITRARY_FILES = "arbitrary_files"
    CELL_CHEMISTRIES = "cell_chemistries"
    CELL_FAMILIES = "cell_families"
    CELL_FORM_FACTORS = "cell_form_factors"
    CELL_MANUFACTURERS = "cell_manufacturers"
    CELL_MODELS = "cell_models"
    CELLS = "cells"
    COLUMN_MAPPINGS = "column_mappings"
    COLUMN_TYPES = "column_types"
    CREATE_TOKEN = "create_token"
    CYCLER_TESTS = "cycler_tests"
    EQUIPMENT = "equipment"
    EQUIPMENT_FAMILIES = "equipment_families"
    EQUIPMENT_MANUFACTURERS = "equipment_manufacturers"
    EQUIPMENT_MODELS = "equipment_models"
    EQUIPMENT_TYPES = "equipment_types"
    EXPERIMENTS = "experiments"
    FILES = "files"
    GALV_STORAGE = "galv_storage"
    HARVEST_ERRORS = "harvest_errors"
    HARVESTERS = "harvesters"
    LABS = "labs"
    LOGIN = "login"
    MONITORED_PATHS = "monitored_paths"
    PARQUET_PARTITIONS = "parquet_partitions"
    SCHEDULE_FAMILIES = "schedule_families"
    SCHEDULE_IDENTIFIERS = "schedule_identifiers"
    SCHEDULES = "schedules"
    SCHEMA_VALIDATIONS = "schema_validations"
    TEAMS = "teams"
    TOKENS = "tokens"
    UNITS = "units"
    USERS = "users"
    VALIDATION_SCHEMAS = "validation_schemas"



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class PatchedScheduleRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A ModelSerializer that maps unrecognised properties in the input to an 'custom_properties' JSONField,
and unpacks the 'custom_properties' JSONField into the output.

The Meta.model must have a custom_properties JSONField.
    """


    class MetaOapg:
        
        class properties:
            family = schemas.StrSchema
            
            
            class schedule_file(
                schemas.BinaryBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'binary'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'schedule_file':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class pybamm_schedule_variables(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
            
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'pybamm_schedule_variables':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class team(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'uri'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'team':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class read_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        2: "POSITIVE_2",
                        1: "POSITIVE_1",
                        0: "POSITIVE_0",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'read_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class edit_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        2: "POSITIVE_2",
                        1: "POSITIVE_1",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'edit_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class delete_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'delete_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class custom_properties(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'custom_properties':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "family": family,
                "schedule_file": schedule_file,
                "pybamm_schedule_variables": pybamm_schedule_variables,
                "team": team,
                "read_access_level": read_access_level,
                "edit_access_level": edit_access_level,
                "delete_access_level": delete_access_level,
                "custom_properties": custom_properties,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["family"]) -> MetaOapg.properties.family: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["schedule_file"]) -> MetaOapg.properties.schedule_file: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pybamm_schedule_variables"]) -> MetaOapg.properties.pybamm_schedule_variables: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["team"]) -> MetaOapg.properties.team: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["read_access_level"]) -> MetaOapg.properties.read_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["edit_access_level"]) -> MetaOapg.properties.edit_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["delete_access_level"]) -> MetaOapg.properties.delete_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_properties"]) -> MetaOapg.properties.custom_properties: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["family", "schedule_file", "pybamm_schedule_variables", "team", "read_access_level", "edit_access_level", "delete_access_level", "custom_properties", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["family"]) -> typing.Union[MetaOapg.properties.family, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["schedule_file"]) -> typing.Union[MetaOapg.properties.schedule_file, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pybamm_schedule_variables"]) -> typing.Union[MetaOapg.properties.pybamm_schedule_variables, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["team"]) -> typing.Union[MetaOapg.properties.team, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["read_access_level"]) -> typing.Union[MetaOapg.properties.read_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["edit_access_level"]) -> typing.Union[MetaOapg.properties.edit_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["delete_access_level"]) -> typing.Union[MetaOapg.properties.delete_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_properties"]) -> typing.Union[MetaOapg.properties.custom_properties, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["family", "schedule_file", "pybamm_schedule_variables", "team", "read_access_level", "edit_access_level", "delete_access_level", "custom_properties", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        family: typing.Union[MetaOapg.properties.family, str, schemas.Unset] = schemas.unset,
        schedule_file: typing.Union[MetaOapg.properties.schedule_file, None, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        pybamm_schedule_variables: typing.Union[MetaOapg.properties.pybamm_schedule_variables, dict, frozendict.frozendict, None, schemas.Unset] = schemas.unset,
        team: typing.Union[MetaOapg.properties.team, None, str, schemas.Unset] = schemas.unset,
        read_access_level: typing.Union[MetaOapg.properties.read_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        edit_access_level: typing.Union[MetaOapg.properties.edit_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        delete_access_level: typing.Union[MetaOapg.properties.delete_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        custom_properties: typing.Union[MetaOapg.properties.custom_properties, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PatchedScheduleRequest':
        return super().__new__(
            cls,
            *_args,
            family=family,
            schedule_file=schedule_file,
            pybamm_schedule_variables=pybamm_schedule_variables,
            team=team,
            read_access_level=read_access_level,
            edit_access_level=edit_access_level,
            delete_access_level=delete_access_level,
            custom_properties=custom_properties,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from galv import schemas  # noqa: F401


class Cell(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A ModelSerializer that maps unrecognised properties in the input to an 'custom_properties' JSONField,
and unpacks the 'custom_properties' JSONField into the output.

The Meta.model must have a custom_properties JSONField.
    """


    class MetaOapg:
        required = {
            "identifier",
            "cycler_tests",
            "permissions",
            "in_use",
            "id",
            "team",
            "family",
            "url",
        }
        
        class properties:
            url = schemas.StrSchema
            id = schemas.UUIDSchema
            identifier = schemas.StrSchema
            family = schemas.StrSchema
            
            
            class cycler_tests(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'cycler_tests':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            in_use = schemas.BoolSchema
            
            
            class team(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'uri'
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'team':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class permissions(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        read = schemas.BoolSchema
                        write = schemas.BoolSchema
                        create = schemas.BoolSchema
                        __annotations__ = {
                            "read": read,
                            "write": write,
                            "create": create,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["read"]) -> MetaOapg.properties.read: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["write"]) -> MetaOapg.properties.write: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["create"]) -> MetaOapg.properties.create: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["read"]) -> typing.Union[MetaOapg.properties.read, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["write"]) -> typing.Union[MetaOapg.properties.write, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["create"]) -> typing.Union[MetaOapg.properties.create, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["read", "write", "create", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    read: typing.Union[MetaOapg.properties.read, bool, schemas.Unset] = schemas.unset,
                    write: typing.Union[MetaOapg.properties.write, bool, schemas.Unset] = schemas.unset,
                    create: typing.Union[MetaOapg.properties.create, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'permissions':
                    return super().__new__(
                        cls,
                        *_args,
                        read=read,
                        write=write,
                        create=create,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class read_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        2: "POSITIVE_2",
                        1: "POSITIVE_1",
                        0: "POSITIVE_0",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'read_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class edit_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        2: "POSITIVE_2",
                        1: "POSITIVE_1",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'edit_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class delete_access_level(
                schemas.EnumBase,
                schemas.IntBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneDecimalMixin
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        4: "POSITIVE_4",
                        3: "POSITIVE_3",
                        schemas.NoneClass.NONE: "NONE",
                    }
                
                @schemas.classproperty
                def POSITIVE_4(cls):
                    return cls(4)
                
                @schemas.classproperty
                def POSITIVE_3(cls):
                    return cls(3)
                
                @schemas.classproperty
                def NONE(cls):
                    return cls(None)
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'delete_access_level':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class custom_properties(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'custom_properties':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "url": url,
                "id": id,
                "identifier": identifier,
                "family": family,
                "cycler_tests": cycler_tests,
                "in_use": in_use,
                "team": team,
                "permissions": permissions,
                "read_access_level": read_access_level,
                "edit_access_level": edit_access_level,
                "delete_access_level": delete_access_level,
                "custom_properties": custom_properties,
            }
    
    identifier: MetaOapg.properties.identifier
    cycler_tests: MetaOapg.properties.cycler_tests
    permissions: MetaOapg.properties.permissions
    in_use: MetaOapg.properties.in_use
    id: MetaOapg.properties.id
    team: MetaOapg.properties.team
    family: MetaOapg.properties.family
    url: MetaOapg.properties.url
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["family"]) -> MetaOapg.properties.family: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cycler_tests"]) -> MetaOapg.properties.cycler_tests: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["in_use"]) -> MetaOapg.properties.in_use: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["team"]) -> MetaOapg.properties.team: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["read_access_level"]) -> MetaOapg.properties.read_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["edit_access_level"]) -> MetaOapg.properties.edit_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["delete_access_level"]) -> MetaOapg.properties.delete_access_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_properties"]) -> MetaOapg.properties.custom_properties: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["url", "id", "identifier", "family", "cycler_tests", "in_use", "team", "permissions", "read_access_level", "edit_access_level", "delete_access_level", "custom_properties", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["url"]) -> MetaOapg.properties.url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["family"]) -> MetaOapg.properties.family: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cycler_tests"]) -> MetaOapg.properties.cycler_tests: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["in_use"]) -> MetaOapg.properties.in_use: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["team"]) -> MetaOapg.properties.team: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["permissions"]) -> MetaOapg.properties.permissions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["read_access_level"]) -> typing.Union[MetaOapg.properties.read_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["edit_access_level"]) -> typing.Union[MetaOapg.properties.edit_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["delete_access_level"]) -> typing.Union[MetaOapg.properties.delete_access_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_properties"]) -> typing.Union[MetaOapg.properties.custom_properties, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["url", "id", "identifier", "family", "cycler_tests", "in_use", "team", "permissions", "read_access_level", "edit_access_level", "delete_access_level", "custom_properties", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        identifier: typing.Union[MetaOapg.properties.identifier, str, ],
        cycler_tests: typing.Union[MetaOapg.properties.cycler_tests, list, tuple, ],
        permissions: typing.Union[MetaOapg.properties.permissions, dict, frozendict.frozendict, ],
        in_use: typing.Union[MetaOapg.properties.in_use, bool, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        team: typing.Union[MetaOapg.properties.team, None, str, ],
        family: typing.Union[MetaOapg.properties.family, str, ],
        url: typing.Union[MetaOapg.properties.url, str, ],
        read_access_level: typing.Union[MetaOapg.properties.read_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        edit_access_level: typing.Union[MetaOapg.properties.edit_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        delete_access_level: typing.Union[MetaOapg.properties.delete_access_level, None, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        custom_properties: typing.Union[MetaOapg.properties.custom_properties, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Cell':
        return super().__new__(
            cls,
            *_args,
            identifier=identifier,
            cycler_tests=cycler_tests,
            permissions=permissions,
            in_use=in_use,
            id=id,
            team=team,
            family=family,
            url=url,
            read_access_level=read_access_level,
            edit_access_level=edit_access_level,
            delete_access_level=delete_access_level,
            custom_properties=custom_properties,
            _configuration=_configuration,
            **kwargs,
        )
